==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>认证超时</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>磁盘文件被占用，无法卸载</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁盘文件被占用，无法弹出</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>光驱正忙，无法弹出</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>设备正忙，无法安全移除</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 卷</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>设备没有正常移除</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>请点击“安全移除”后，再断开连接</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">光驱正忙，无法弹出</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">设备正忙，无法安全移除</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>无法卸载设备</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>磁盘由用户“%1”挂载，您没有卸载权限。</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>找不到对应的挂载设备</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>磁盘列表</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁盘</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>全部弹出</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>设备已被安全移除</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>禁止访问</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>您没有权限访问该文件夹</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>正在扫描当前设备，是否终止扫描？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>终止</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.8.orig.tar.xz: dde-file-manager-5.6.8/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>认证超时</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>磁盘文件被占用，无法卸载</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁盘文件被占用，无法弹出</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>光驱正忙，无法弹出</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>设备正忙，无法安全移除</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 卷</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>设备没有正常移除</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>请点击“安全移除”后，再断开连接</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>无法卸载设备</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>磁盘由用户“%1”挂载，您没有卸载权限。</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>找不到对应的挂载设备</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>磁盘列表</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁盘</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>全部弹出</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>设备已被安全移除</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>禁止访问</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>您没有权限访问该文件夹</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>正在扫描当前设备，是否终止扫描？</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>确 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>终 止</translation>
    </message>
</context>
</TS>
